workspace_root

Function workspace_root 

pub fn workspace_root() -> PathBuf
The repository root.

Discovered by walking up from the current directory rather than taken from CARGO_MANIFEST_DIR: as a library, this crate’s manifest directory is somewhere in the Cargo registry, not in the project being worked on.